==> verticalpodautoscaler-model-v1-6.1.1-sources.jar: io/fabric8/verticalpodautoscaler/api/model/v1/VerticalPodAutoscalerStatusFluent.java <==
package io.fabric8.verticalpodautoscaler.api.model.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface VerticalPodAutoscalerStatusFluent<A extends VerticalPodAutoscalerStatusFluent<A>> extends Fluent<A>{
  public A addToConditions(Integer index,VerticalPodAutoscalerCondition item);
  public A setToConditions(Integer index,VerticalPodAutoscalerCondition item);
  public A addToConditions(io.fabric8.verticalpodautoscaler.api.model.v1.VerticalPodAutoscalerCondition... items);
  public A addAllToConditions(Collection<VerticalPodAutoscalerCondition> items);
  public A removeFromConditions(io.fabric8.verticalpodautoscaler.api.model.v1.VerticalPodAutoscalerCondition... items);
  public A removeAllFromConditions(Collection<VerticalPodAutoscalerCondition> items);
  public A removeMatchingFromConditions(Predicate<VerticalPodAutoscalerConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<VerticalPodAutoscalerCondition> getConditions();
  public List<VerticalPodAutoscalerCondition> buildConditions();
  public VerticalPodAutoscalerCondition buildCondition(Integer index);
  public VerticalPodAutoscalerCondition buildFirstCondition();
  public VerticalPodAutoscalerCondition buildLastCondition();
  public VerticalPodAutoscalerCondition buildMatchingCondition(Predicate<VerticalPodAutoscalerConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<VerticalPodAutoscalerConditionBuilder> predicate);
  public A withConditions(List<VerticalPodAutoscalerCondition> conditions);
  public A withConditions(io.fabric8.verticalpodautoscaler.api.model.v1.VerticalPodAutoscalerCondition... conditions);
  public Boolean hasConditions();
  public A addNewCondition(String lastTransitionTime,String message,String reason,String status,String type);
  public VerticalPodAutoscalerStatusFluent.ConditionsNested<A> addNewCondition();
  public VerticalPodAutoscalerStatusFluent.ConditionsNested<A> addNewConditionLike(VerticalPodAutoscalerCondition item);
  public VerticalPodAutoscalerStatusFluent.ConditionsNested<A> setNewConditionLike(Integer index,VerticalPodAutoscalerCondition item);
  public VerticalPodAutoscalerStatusFluent.ConditionsNested<A> editCondition(Integer index);
  public VerticalPodAutoscalerStatusFluent.ConditionsNested<A> editFirstCondition();
  public VerticalPodAutoscalerStatusFluent.ConditionsNested<A> editLastCondition();
  public VerticalPodAutoscalerStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<VerticalPodAutoscalerConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildRecommendation instead.
   * @return The buildable object.
   */
  @Deprecated
  public RecommendedPodResources getRecommendation();
  public RecommendedPodResources buildRecommendation();
  public A withRecommendation(RecommendedPodResources recommendation);
  public Boolean hasRecommendation();
  public VerticalPodAutoscalerStatusFluent.RecommendationNested<A> withNewRecommendation();
  public VerticalPodAutoscalerStatusFluent.RecommendationNested<A> withNewRecommendationLike(RecommendedPodResources item);
  public VerticalPodAutoscalerStatusFluent.RecommendationNested<A> editRecommendation();
  public VerticalPodAutoscalerStatusFluent.RecommendationNested<A> editOrNewRecommendation();
  public VerticalPodAutoscalerStatusFluent.RecommendationNested<A> editOrNewRecommendationLike(RecommendedPodResources item);
  public interface ConditionsNested<N> extends Nested<N>,VerticalPodAutoscalerConditionFluent<VerticalPodAutoscalerStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  public interface RecommendationNested<N> extends Nested<N>,RecommendedPodResourcesFluent<VerticalPodAutoscalerStatusFluent.RecommendationNested<N>>{
    public N and();
    public N endRecommendation();
    
  }
  
}

==> verticalpodautoscaler-model-v1-6.7.2-sources.jar: io/fabric8/verticalpodautoscaler/api/model/v1/VerticalPodAutoscalerStatusFluent.java <==
package io.fabric8.verticalpodautoscaler.api.model.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface VerticalPodAutoscalerStatusFluent<A extends VerticalPodAutoscalerStatusFluent<A>> extends Fluent<A>{
  public A addToConditions(int index,VerticalPodAutoscalerCondition item);
  public A setToConditions(int index,VerticalPodAutoscalerCondition item);
  public A addToConditions(io.fabric8.verticalpodautoscaler.api.model.v1.VerticalPodAutoscalerCondition... items);
  public A addAllToConditions(Collection<VerticalPodAutoscalerCondition> items);
  public A removeFromConditions(io.fabric8.verticalpodautoscaler.api.model.v1.VerticalPodAutoscalerCondition... items);
  public A removeAllFromConditions(Collection<VerticalPodAutoscalerCondition> items);
  public A removeMatchingFromConditions(Predicate<VerticalPodAutoscalerConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<VerticalPodAutoscalerCondition> getConditions();
  public List<VerticalPodAutoscalerCondition> buildConditions();
  public VerticalPodAutoscalerCondition buildCondition(int index);
  public VerticalPodAutoscalerCondition buildFirstCondition();
  public VerticalPodAutoscalerCondition buildLastCondition();
  public VerticalPodAutoscalerCondition buildMatchingCondition(Predicate<VerticalPodAutoscalerConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<VerticalPodAutoscalerConditionBuilder> predicate);
  public A withConditions(List<VerticalPodAutoscalerCondition> conditions);
  public A withConditions(io.fabric8.verticalpodautoscaler.api.model.v1.VerticalPodAutoscalerCondition... conditions);
  public Boolean hasConditions();
  public A addNewCondition(String lastTransitionTime,String message,String reason,String status,String type);
  public VerticalPodAutoscalerStatusFluent.ConditionsNested<A> addNewCondition();
  public VerticalPodAutoscalerStatusFluent.ConditionsNested<A> addNewConditionLike(VerticalPodAutoscalerCondition item);
  public VerticalPodAutoscalerStatusFluent.ConditionsNested<A> setNewConditionLike(int index,VerticalPodAutoscalerCondition item);
  public VerticalPodAutoscalerStatusFluent.ConditionsNested<A> editCondition(int index);
  public VerticalPodAutoscalerStatusFluent.ConditionsNested<A> editFirstCondition();
  public VerticalPodAutoscalerStatusFluent.ConditionsNested<A> editLastCondition();
  public VerticalPodAutoscalerStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<VerticalPodAutoscalerConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildRecommendation instead.
   * @return The buildable object.
   */
  @Deprecated
  public RecommendedPodResources getRecommendation();
  public RecommendedPodResources buildRecommendation();
  public A withRecommendation(RecommendedPodResources recommendation);
  public Boolean hasRecommendation();
  public VerticalPodAutoscalerStatusFluent.RecommendationNested<A> withNewRecommendation();
  public VerticalPodAutoscalerStatusFluent.RecommendationNested<A> withNewRecommendationLike(RecommendedPodResources item);
  public VerticalPodAutoscalerStatusFluent.RecommendationNested<A> editRecommendation();
  public VerticalPodAutoscalerStatusFluent.RecommendationNested<A> editOrNewRecommendation();
  public VerticalPodAutoscalerStatusFluent.RecommendationNested<A> editOrNewRecommendationLike(RecommendedPodResources item);
  public interface ConditionsNested<N> extends Nested<N>,VerticalPodAutoscalerConditionFluent<VerticalPodAutoscalerStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  public interface RecommendationNested<N> extends Nested<N>,RecommendedPodResourcesFluent<VerticalPodAutoscalerStatusFluent.RecommendationNested<N>>{
    public N and();
    public N endRecommendation();
    
  }
  
}
